@@ -37,7 +37,6 @@ const (
 	// translates to the br-nexthop's IP address
 	localnetGatewayNextHopMac = "00:00:a9:fe:21:01"
 	iptableNodePortChain      = "OVN-KUBE-NODEPORT"
-	localnetGatewayMac        = "00:00:a9:fe:21:02"
 )
 
 type iptRule struct {
@@ -91,6 +90,8 @@ func delIptRules(ipt util.IPTablesHelper, rules []iptRule) {
 func generateGatewayNATRules(ifname string, ip net.IP) []iptRule {
 	// Allow packets to/from the gateway interface in case defaults deny
 	rules := make([]iptRule, 0)
+	// Block MCS
+	generateBlockMCSRules(&rules)
 	rules = append(rules, iptRule{
 		table: "filter",
 		chain: "FORWARD",
@@ -184,13 +185,11 @@ func initLocalnetGateway(nodeName string, subnet *net.IPNet, wf *factory.WatchFa
 		return err
 	}
 
-	gwMacAddress, _ := net.ParseMAC(localnetGatewayMac)
-
 	err = util.SetL3GatewayConfig(nodeAnnotator, &util.L3GatewayConfig{
 		Mode:           config.GatewayModeLocal,
 		ChassisID:      chassisID,
 		InterfaceID:    ifaceID,
-		MACAddress:     gwMacAddress,
+		MACAddress:     macAddress,
 		IPAddresses:    []*net.IPNet{gatewayIPCIDR},
 		NextHops:       []net.IP{gatewayNextHop},
 		NodePortEnable: config.Gateway.NodeportEnable,
